//
//  TGOfflineTests.m
//  Tapglue Tests
//
//  Created by Martin Stemmle on 09/06/15.
//  Copyright (c) 2015 Tapglue (https://www.tapglue.com/). All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
//

#import "TGIntegrationTestCase.h"
#import "TGEventManager.h"

@interface TGOfflineTests : TGIntegrationTestCase

@end

@implementation TGOfflineTests

- (void)testFeedCache {
    [Tapglue setUpWithAppToken:self.appToken andConfig:self.config];
    expect([Tapglue cachedFeedForCurrentUser]).to.beNil();
    [self runTestBlockAfterLogin:^(XCTestExpectation *expectation) {
        expect([Tapglue cachedFeedForCurrentUser]).to.beKindOfOrNil([NSArray class]);

        [Tapglue retrieveFeedForCurrentUserWithCompletionBlock:^(NSArray *events, NSInteger unreadCount, NSError *error) {
            expect(error).to.beNil();
            expect([Tapglue cachedFeedForCurrentUser]).to.beKindOfOrNil([NSArray class]);
            expect([Tapglue cachedFeedForCurrentUser]).to.equal(events);

            XCTAssertGreaterThan(events.count, 0, @"This test only works properly if the feed is not empty");

            Tapglue *tgInstance = [Tapglue sharedInstance];
            [tgInstance.eventManager archive];
            [Tapglue setUpWithAppToken:self.appToken andConfig:self.config]; // create a new Tapglue instance to release all caches
            expect([Tapglue sharedInstance]).toNot.equal(tgInstance);


            NSArray *cachedFeed = [Tapglue cachedFeedForCurrentUser];
            expect(cachedFeed).to.beKindOf([NSArray class]);
            expect(cachedFeed.count).to.equal(events.count);

            [expectation fulfill];
        }];
    }];
}


// TODO: same test for the unread feed

// TODO: test for unread count caching

@end
